# mypy-boto3-service-quotas

Type annotations for
[boto3.ServiceQuotas 1.10.40](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/service-quotas.html#ServiceQuotas) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

More information can be found [here](https://vemel.github.io/mypy_boto3/).

- [mypy-boto3-service-quotas](#mypy-boto3-service-quotas)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
    - [Code auto-complete](#code-auto-complete)
  - [How it works](#how-it-works)

## How to use

### Type checking

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `ServiceQuotas` service.

```bash
python -m pip install boto3-stubs[mypy-boto3-service-quotas]
```

Use `boto3` with `mypy_boto3` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3 import service_quotas
# alternative import if you do not want to install mypy_boto3 package
# import mypy_boto3_service_quotas as service_quotas

# Use this client as usual, now mypy can check if your code is valid.
# Check if your IDE supports function overloads,
# you probably do not need explicit type annotations
# client = boto3.client("service-quotas")
client: service_quotas.ServiceQuotasClient = boto3.client("service-quotas")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: service_quotas.ServiceQuotasClient = session.client("service-quotas")


# Paginators need type annotation on creation
list_aws_default_service_quotas_paginator: service_quotas.ListAWSDefaultServiceQuotasPaginator = client.get_paginator("list_aws_default_service_quotas")
list_requested_service_quota_change_history_paginator: service_quotas.ListRequestedServiceQuotaChangeHistoryPaginator = client.get_paginator("list_requested_service_quota_change_history")
list_requested_service_quota_change_history_by_quota_paginator: service_quotas.ListRequestedServiceQuotaChangeHistoryByQuotaPaginator = client.get_paginator("list_requested_service_quota_change_history_by_quota")
list_service_quota_increase_requests_in_template_paginator: service_quotas.ListServiceQuotaIncreaseRequestsInTemplatePaginator = client.get_paginator("list_service_quota_increase_requests_in_template")
list_service_quotas_paginator: service_quotas.ListServiceQuotasPaginator = client.get_paginator("list_service_quotas")
list_services_paginator: service_quotas.ListServicesPaginator = client.get_paginator("list_services")
```

## How it works

Fully automated [builder](https://github.com/vemel/mypy_boto3) carefully generates
type annotations for each service, patiently waiting for `boto3` updates. It delivers
a drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type annotations
  extracted from the documentation (blame `botocore` docs if types are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) for readability.